"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
const path = require("path");
const util = require("util");
const metadataInfoManager_1 = require("./metadataInfoManager");
const sfdxPackageDirectories_1 = require("./sfdxPackageDirectories");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
class Validations {
    static async validateSourcePath(sourcePath) {
        this.isValidPath(sourcePath);
        await this.isValidPackageSource(sourcePath);
    }
    static isValidPath(sourcePath) {
        if (!fs.existsSync(sourcePath)) {
            throw Error(messages.getMessage('path_does_not_exist'));
        }
    }
    static async isValidPackageSource(sourcePath) {
        if (!(await sfdxPackageDirectories_1.default.pathIsInPackageDirectory(sourcePath))) {
            throw Error(messages.getMessage('path_not_in_package_directory'));
        }
    }
    static async isValidProject() {
        const project = await command_1.core.SfdxProject.resolve();
        if (!project) {
            throw new Error(messages.getMessage('error_invalid_project'));
        }
    }
    static validateMetadataInfo(metadataInfo, sourcePath) {
        this.isValidMetadataInfo(metadataInfo, sourcePath);
        this.isParentFolderValid(metadataInfo, sourcePath);
    }
    static isValidMetadataInfo(metadataInfo, sourcePath) {
        if (util.isNullOrUndefined(metadataInfo)) {
            const metadataInfoManager = new metadataInfoManager_1.default();
            throw Error(messages.getMessage('path_not_supported', [
                sourcePath,
                metadataInfoManager.getSupportedMetadataTypes().join(', ')
            ]));
        }
    }
    static isParentFolderValid(metadataInfo, sourcePath) {
        if (!util.isNullOrUndefined(metadataInfo.parentFolder) &&
            !sourcePath.match(new RegExp(metadataInfo.parentFolder +
                `${path.sep}` +
                '[^\\|/]*' +
                `${path.sep}` +
                path.basename(sourcePath) +
                '$'))) {
            throw Error(messages.getMessage('path_not_supported_invalid_folder', [
                sourcePath,
                metadataInfo.suffix,
                `${metadataInfo.parentFolder}${path.sep}<BundleName>`
            ]));
        }
    }
}
exports.default = Validations;
//# sourceMappingURL=validations.js.map